@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2023 Vaclav Slavik
+ *  Copyright (C) 1999-2024 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
@@ -26,12 +26,12 @@
 
 #include "cat_sorting.h"
 
-#include <unicode/unistr.h>
 #include "str_helpers.h"
 
 #include <wx/config.h>
 #include <wx/log.h>
 
+
 /*static*/ SortOrder SortOrder::Default()
 {
     SortOrder order;
@@ -82,32 +82,44 @@ void SortOrder::Save()
 CatalogItemsComparator::CatalogItemsComparator(const Catalog& catalog, const SortOrder& order)
     : m_catalog(catalog), m_order(order)
 {
-    UErrorCode err = U_ZERO_ERROR;
+    if (m_order.by == SortOrder::By_Translation && !m_catalog.HasCapability(Catalog::Cap::Translations))
+        m_order.by = SortOrder::By_FileOrder;
+
+    switch (m_order.by)
+    {
+        case SortOrder::By_Translation:
+            m_collator.reset(new unicode::Collator(catalog.GetLanguage(), unicode::Collator::case_insensitive));
+            break;
+
+        case SortOrder::By_FileOrder:
+            // we still need collator for e.g. comparing contexts, use source language for that
+        case SortOrder::By_Source:
+            m_collator.reset(new unicode::Collator(catalog.GetSourceLanguage(), unicode::Collator::case_insensitive));
+            break;
+    }
+
+    // Prepare cache for faster comparison. ICU uses UTF-16 internally, we can significantly
+    // speed up comparisons by doing string conversion in advance, in O(n) time and space, if
+    // the platform's native representation is UTF-32 or -8 (which it is on non-Windows).
+    // Moreover, the additional processing of removing accelerators is also done only once
+    // on all platforms, resulting in massive speedups on Windows too.
     switch (m_order.by)
     {
         case SortOrder::By_Source:
-            m_collator.reset(icu::Collator::createInstance(catalog.GetSourceLanguage().ToIcu(), err));
+            m_sortKeys.reserve(m_catalog.GetCount());
+            for (auto& i: m_catalog.items())
+                m_sortKeys.push_back(ConvertToSortKey(i->GetString()));
             break;
 
         case SortOrder::By_Translation:
-            m_collator.reset(icu::Collator::createInstance(catalog.GetLanguage().ToIcu(), err));
+            m_sortKeys.reserve(m_catalog.GetCount());
+            for (auto& i: m_catalog.items())
+                m_sortKeys.push_back(ConvertToSortKey(i->GetTranslation()));
             break;
 
         case SortOrder::By_FileOrder:
             break;
     }
-
-    if (!U_SUCCESS(err) || err == U_USING_FALLBACK_WARNING)
-    {
-        wxLogTrace("poedit", "warning: not using collation for %s (%s)",
-                   catalog.GetLanguage().Code(), u_errorName(err));
-    }
-
-    if (m_collator)
-    {
-        // Case-insensitive comparison:
-        m_collator->setStrength(icu::Collator::SECONDARY);
-    }
 }
 
 
@@ -155,7 +167,8 @@ bool CatalogItemsComparator::operator()(int i, int j) const
             return false;
         else if ( a.HasContext() && b.HasContext() )
         {
-            int r = CompareStrings(a.GetContext(), b.GetContext());
+            // we don't want to apply translation string pre-processing to contexts, use collator directly
+            auto r = m_collator->compare(a.GetContext(), b.GetContext());
             if ( r != 0 )
                 return r < 0;
         }
@@ -169,16 +182,9 @@ bool CatalogItemsComparator::operator()(int i, int j) const
         }
 
         case SortOrder::By_Source:
-        {
-            int r = CompareStrings(a.GetString(), b.GetString());
-            if ( r != 0 )
-                return r < 0;
-            break;
-        }
-
         case SortOrder::By_Translation:
         {
-            int r = CompareStrings(a.GetTranslation(), b.GetTranslation());
+            auto r = m_collator->compare(m_sortKeys[i], m_sortKeys[j]);
             if ( r != 0 )
                 return r < 0;
             break;
@@ -190,29 +196,3 @@ bool CatalogItemsComparator::operator()(int i, int j) const
     // ordering.
     return i < j;
 }
-
-
-int CatalogItemsComparator::CompareStrings(wxString a, wxString b) const
-{
-    a.Replace("&", "");
-    a.Replace("_", "");
-
-    b.Replace("&", "");
-    b.Replace("_", "");
-
-    if (m_collator)
-    {
-        UErrorCode err = U_ZERO_ERROR;
-#if wxUSE_UNICODE_UTF8
-        return m_collator->compareUTF8(a.wx_str(), b.wx_str(), err);
-#elif SIZEOF_WCHAR_T == 2
-        return m_collator->compare(a.wx_str(), a.length(), b.wx_str(), b.length(), err);
-#else
-        return m_collator->compare(str::to_icu(a), str::to_icu(b), err);
-#endif
-    }
-    else
-    {
-        return a.CmpNoCase(b);
-    }
-}
