@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2023 Vaclav Slavik
+ *  Copyright (C) 1999-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -214,7 +214,7 @@ void Catalog::HeaderData::UpdateDict()
     SetHeader("Content-Type", "text/plain; charset=" + Charset);
     SetHeader("Content-Transfer-Encoding", "8bit");
     SetHeaderNotEmpty("Language", Lang.Code());
-    SetHeader("X-Generator", wxString::FromAscii("Poedit " POEDIT_VERSION));
+    SetHeader("X-Generator", wxString::FromAscii("Poedit " POEDIT_VERSION_SHORT));
 
     // Set extended information:
 
@@ -229,23 +229,9 @@ void Catalog::HeaderData::UpdateDict()
         SetHeader("X-Poedit-KeywordsList", kw);
     }
 
-    unsigned i;
-    bool noBookmarkSet = true;
-    wxString bk;
-    for (i = 0; i < BOOKMARK_LAST ; i++)
-    {
-        noBookmarkSet = noBookmarkSet && (Bookmarks[i] == NO_BOOKMARK);
-        bk += wxString() << Bookmarks[i] << _T(',');
-    }
-    bk.RemoveLast();
-    if (noBookmarkSet)
-        DeleteHeader("X-Poedit-Bookmarks");
-    else
-        SetHeader("X-Poedit-Bookmarks", bk);
-
     SetHeaderNotEmpty("X-Poedit-Basepath", BasePath);
 
-    i = 0;
+    unsigned i = 0;
     while (true)
     {
         wxString path;
@@ -343,7 +329,7 @@ void Catalog::HeaderData::ParseDict()
         wxString X_Language = GetHeader("X-Poedit-Language");
         wxString X_Country = GetHeader("X-Poedit-Country");
         if ( !X_Language.empty() )
-            Lang = Language::FromLegacyNames(X_Language.ToStdString(), X_Country.ToStdString());
+            Lang = Language::FromLegacyNames(X_Language.utf8_string(), X_Country.utf8_string());
     }
 
     DeleteHeader("X-Poedit-Language");
@@ -379,27 +365,8 @@ void Catalog::HeaderData::ParseDict()
         }
     }
 
-    int i;
-    for(i = 0; i < BOOKMARK_LAST; i++)
-    {
-      Bookmarks[i] = NO_BOOKMARK;
-    }
-    wxString bk = GetHeader("X-Poedit-Bookmarks");
-    if (!bk.empty())
-    {
-        wxStringTokenizer tkn(bk, ",");
-        i=0;
-        long int val;
-        while (tkn.HasMoreTokens() && i<BOOKMARK_LAST)
-        {
-            tkn.GetNextToken().ToLong(&val);
-            Bookmarks[i] = (int)val;
-            i++;
-        }
-    }
-
     SearchPaths.clear();
-    i = 0;
+    int i = 0;
     while (true)
     {
         wxString path;
@@ -503,12 +470,7 @@ Catalog::HeaderData::Find(const wxString& key) const
 Catalog::Catalog(Type type)
 {
     m_fileType = type;
-
     m_header.BasePath = wxEmptyString;
-    for(int i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
-    {
-        m_header.Bookmarks[i] = -1;
-    }
 }
 
 
@@ -589,26 +551,28 @@ int Catalog::FindItemIndexByLine(int lineno)
     return last;
 }
 
-int Catalog::SetBookmark(int id, Bookmark bookmark)
+
+bool Catalog::RemoveSameAsSourceTranslations()
 {
-    int previous = (bookmark==NO_BOOKMARK)?-1:m_header.Bookmarks[bookmark];
-    if (previous >= (int)m_items.size())
-        previous = -1;
+    bool changed = false;
 
-    // unset previous bookmarks, if any
-    Bookmark bk = m_items[id]->GetBookmark();
-    if (bk != NO_BOOKMARK)
-        m_header.Bookmarks[bk] = -1;
-    if (previous > -1)
-        m_items[previous]->SetBookmark(NO_BOOKMARK);
+    for (auto& i: m_items)
+    {
+        if (i ->GetString() == i->GetTranslation())
+        {
+            if (i->HasPlural())
+            {
+                // we can only easily do this operation for languages that have singular+plural, skip everything else:
+                if (GetPluralFormsCount() != 2 || i->GetPluralString() != i->GetTranslation(1))
+                    continue;
+            }
 
-    // set new bookmark
-    m_items[id]->SetBookmark(bookmark);
-    if (bookmark != NO_BOOKMARK)
-        m_header.Bookmarks[bookmark] = id;
+            i->ClearTranslation();
+            changed = true;
+        }
+    }
 
-    // return id of previous item for that bookmark
-    return previous;
+    return changed;
 }
 
 
@@ -662,7 +626,7 @@ wxString Catalog::GetTypesFileMask(std::initializer_list<Type> types)
 void Catalog::SetFileName(const wxString& fn)
 {
     wxFileName f(fn);
-    f.Normalize(wxPATH_NORM_DOTS | wxPATH_NORM_ABSOLUTE);
+    f.MakeAbsolute();
     m_fileName = f.GetFullPath();
 }
 
@@ -698,7 +662,7 @@ wxString GetSourcesPath(const wxString& fileName, const Catalog::HeaderData& hea
     }
 
     wxFileName root = wxFileName::DirName(basepath);
-    root.Normalize(wxPATH_NORM_DOTS | wxPATH_NORM_ABSOLUTE);
+    root.MakeAbsolute();
 
     if (kind == SourcesPath::Root)
     {
@@ -766,7 +730,7 @@ bool Catalog::HasSourcesAvailable() const
         auto root = GetSourcesRootPath();
         if (root == wxGetUserHome() ||
             root == wxStandardPaths::Get().GetDocumentsDir() ||
-            root.EndsWith(wxString(wxFILE_SEP_PATH) + "Desktop" + wxFILE_SEP_PATH))
+            root.ends_with(wxString(wxFILE_SEP_PATH) + "Desktop" + wxFILE_SEP_PATH))
         {
             return false;
         }
@@ -898,21 +862,21 @@ wxString CatalogItem::GetFlags() const
     }
 }
 
-wxString CatalogItem::GetFormatFlag() const
+std::string CatalogItem::GetFormatFlag() const
 {
     if (m_moreFlags.empty())
-        return wxString();
+        return std::string();
 
     auto pos = m_moreFlags.find(wxS("-format"));
     if (pos == wxString::npos)
-        return wxString();
+        return std::string();
     auto space = m_moreFlags.find_last_of(" \t", pos);
     auto format = (space == wxString::npos)
                     ? m_moreFlags.substr(0, pos)
                     : m_moreFlags.substr(space+1, pos-space-1);
-    if (format.StartsWith("no-"))
-        return wxString();
-    return format;
+    if (format.starts_with("no-"))
+        return std::string();
+    return std::string(format.begin(), format.end());
 }
 
 void CatalogItem::SetFuzzy(bool fuzzy)
@@ -927,7 +891,7 @@ void CatalogItem::SetFuzzy(bool fuzzy)
 wxString CatalogItem::GetTranslation(unsigned idx) const
 {
     if (idx >= GetNumberOfTranslations())
-        return wxEmptyString;
+        return wxString();
     else
         return m_translations[idx];
 }
@@ -1037,9 +1001,9 @@ wxString CatalogItem::GetOldMsgid() const
             line.RemoveLast();
         if (line[0] == '"')
             line.Remove(0, 1);
-        if (line.StartsWith("msgid \""))
+        if (line.starts_with("msgid \""))
             line.Remove(0, 7);
-        else if (line.StartsWith("msgid_plural \""))
+        else if (line.starts_with("msgid_plural \""))
             line.replace(0, 14, "\n");
         s += UnescapeCString(line);
     }
@@ -1123,7 +1087,7 @@ void Catalog::PostCreation()
             }
             if (!allText.empty())
             {
-                lang = Language::TryDetectFromText(allText.utf8_str());
+                lang = Language::TryDetectFromText(str::to_utf8(allText));
                 wxLogTrace("poedit", "detected translation language is '%s'", GetLanguage().Code());
             }
         }
@@ -1215,6 +1179,9 @@ void Catalog::SideloadSourceDataFromReferenceFile(CatalogPtr ref)
             continue;
 
         auto& rdata = *ri->second;
+        if (rdata.GetTranslation().empty())
+            continue;
+
         auto d = std::make_shared<SideloadedItemData>();
         d->source_string = rdata.GetTranslation();
         if (rdata.HasPlural())
