@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2023 Vaclav Slavik
+ *  Copyright (C) 1999-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -533,9 +533,9 @@ wxString POCatalogParser::ReadTextLine()
 
         // gettext tools don't include (extracted) comments in wrapping, so they can't
         // be reliably used to detect file's wrapping either; just skip them.
-        if (!ln.StartsWith(wxS("#. ")) && !ln.StartsWith(wxS("# ")))
+        if (!ln.starts_with(wxS("#. ")) && !ln.starts_with(wxS("# ")))
         {
-            if (ln.EndsWith(wxS("\\n\"")))
+            if (ln.ends_with(wxS("\\n\"")))
             {
                 // Similarly, lines ending with \n are always wrapped, so skip that too.
                 m_lastLineHardWrapped = true;
@@ -737,7 +737,7 @@ bool POLoadParser::OnEntry(const wxString& msgid,
             // https://groups.google.com/d/topic/poedit/j41KuvXtVUU/discussion
             // As a workaround, just filter them out.
             // FIXME: Fix this properly... but not using msgcat in the first place
-            if (i.StartsWith(MSGCAT_CONFLICT_MARKER) && i.EndsWith(MSGCAT_CONFLICT_MARKER))
+            if (i.starts_with(MSGCAT_CONFLICT_MARKER) && i.ends_with(MSGCAT_CONFLICT_MARKER))
                 continue;
             d->AddExtractedComments(i);
         }
@@ -910,7 +910,7 @@ void POCatalog::Load(const wxString& po_file, int flags)
 
     wxString ext;
     wxFileName::SplitPath(po_file, nullptr, nullptr, &ext);
-    if (ext.CmpNoCase("pot") == 0)
+    if (ext.CmpNoCase("pot") == 0 || (flags & CreationFlag_IgnoreTranslations))
         m_fileType = Type::POT;
     else
         m_fileType = Type::PO;
@@ -951,23 +951,6 @@ void POCatalog::Load(const wxString& po_file, int flags)
 
     m_sourceLanguage = parser.GetSpecifiedMsgidLanguage();  // may be, and likely will, invalid
 
-    // now that the catalog is loaded, update its items with the bookmarks
-    for (unsigned i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
-    {
-        if (m_header.Bookmarks[i] == -1)
-            continue;
-
-        if (m_header.Bookmarks[i] < (int)m_items.size())
-        {
-            m_items[m_header.Bookmarks[i]]->SetBookmark(
-                    static_cast<Bookmark>(i));
-        }
-        else // invalid bookmark
-        {
-            m_header.Bookmarks[i] = -1;
-        }
-    }
-
     m_fileCRLF = GetFileCRLFFormat(f);
     m_fileWrappingWidth = parser.GetWrappingWidth();
     wxLogTrace("poedit", "detect line wrapping: %d", m_fileWrappingWidth);
@@ -997,7 +980,7 @@ void POCatalog::FixupCommonIssues()
     // this by removing the flag ourselves, as translators can rarely influence it:
     for (auto& i: items())
     {
-        if (i->GetFormatFlag() == wxS("php"))
+        if (i->GetFormatFlag() == "php")
         {
             auto s = i->GetRawString();
             if (s.Contains(wxS("% ")) && !s.Contains(wxS("%% ")))
@@ -1032,7 +1015,7 @@ void POCatalog::FixupCommonIssues()
 
     if (!pluralForms.empty())
     {
-        if (!pluralForms.EndsWith(";"))
+        if (!pluralForms.ends_with(";"))
         {
             pluralForms += ";";
             m_header.SetHeader("Plural-Forms", pluralForms);
@@ -1055,8 +1038,6 @@ void POCatalog::Clear()
 {
     // Catalog base class fields:
     m_items.clear();
-    for (int i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
-        m_header.Bookmarks[i] = -1;
 
     // PO-specific fields:
     m_deletedItems.clear();
@@ -1493,12 +1474,14 @@ bool POCatalog::DoSaveOnly(const wxString& po_file, wxTextFileType crlf)
 
 bool POCatalog::DoSaveOnly(wxTextBuffer& f, wxTextFileType crlf)
 {
+    const bool isPOT = m_fileType == Type::POT;
+
     /* Save .po file: */
     if (!m_header.Charset || m_header.Charset == "CHARSET")
         m_header.Charset = "UTF-8";
 
     SaveMultiLines(f, m_header.Comment);
-    if (m_fileType == Type::POT)
+    if (isPOT)
         f.AddLine(wxS("#, fuzzy"));
     f.AddLine(wxS("msgid \"\""));
     f.AddLine(wxS("msgstr \"\""));
@@ -1549,8 +1532,15 @@ bool POCatalog::DoSaveOnly(wxTextBuffer& f, wxTextFileType crlf)
         }
         else
         {
-            dummy = FormatStringForFile(data->GetTranslation());
-            SaveMultiLines(f, wxS("msgstr \"") + dummy + wxS("\""));
+            if (isPOT)
+            {
+                f.AddLine(wxS("msgstr \"\""));
+            }
+            else
+            {
+                dummy = FormatStringForFile(data->GetTranslation());
+                SaveMultiLines(f, wxS("msgstr \"") + dummy + wxS("\""));
+            }
         }
         f.AddLine(wxEmptyString);
     }
