@@ -617,11 +617,13 @@ public:
         if (!target)
         {
             auto ws_after = m_node.first_child();
-            auto source = m_node.child("source");
-            target = m_node.insert_child_after("target", source);
+            auto prev = m_node.child("seg-source");
+            if (!prev)
+                prev = m_node.child("source");
+            target = m_node.insert_child_after("target", prev);
             // indent the <target> tag in the same way <source> is indented under its parent:
             if (ws_after.type() == node_pcdata)
-                m_node.insert_child_after(node_pcdata, source).text() = ws_after.text().get();
+                m_node.insert_child_after(node_pcdata, prev).text() = ws_after.text().get();
         }
 
         auto trans = GetTranslation();
@@ -636,6 +638,9 @@ public:
         else // no translation
         {
             remove_all_children(target);
+            // Ensure the node is shown as <target></target> rather than <target/>.
+            // The spec is unclear in this regard and the former is more expected.
+            target.text() = "";
         }
 
         Impl_UpdateTargetState(target, !trans.empty(), m_isFuzzy);
@@ -819,6 +824,9 @@ public:
             m_node.remove_attribute("state");
             m_node.remove_attribute("subState");
             remove_all_children(target);
+            // Ensure the node is shown as <target></target> rather than <target/>.
+            // The spec is unclear in this regard and the former is more expected.
+            target.text() = "";
         }
     }
 
