@@ -83,16 +83,11 @@ ServiceSelectionPanel::ServiceSelectionPanel(wxWindow *parent) : wxPanel(parent,
 
 void ServiceSelectionPanel::AddService(AccountDetailPanel *account)
 {
-    bool isFirst = GetChildren().empty();
-    auto content = CreateServiceContent(account);
-    size_t pos = (!isFirst && time(NULL) % 2 == 0 /* aka rand() w/o need to seed */)
-                 ? m_sizer->GetItemCount()
-                 : 0;
-    size_t posLine = (pos == 0) ? 1 : pos;
+    if (!GetChildren().empty())
+        m_sizer->Add(new wxStaticLine(this, wxID_ANY), wxSizerFlags().Expand().Border(wxTOP|wxBOTTOM, PX(24)));
 
-    m_sizer->Insert(pos, content, wxSizerFlags(1).Expand());
-    if (!isFirst)
-        m_sizer->Insert(posLine, new wxStaticLine(this, wxID_ANY), wxSizerFlags().Expand().Border(wxTOP|wxBOTTOM, PX(24)));
+    auto content = CreateServiceContent(account);
+    m_sizer->Add(content, wxSizerFlags(1).Expand());
 }
 
 
@@ -149,10 +144,7 @@ AccountsPanel::AccountsPanel(wxWindow *parent, int flags) : wxPanel(parent, wxID
     m_panelsBook = new wxSimplebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL | MSW_OR_OTHER(wxBORDER_SIMPLE, wxBORDER_SUNKEN));
     ColorScheme::SetupWindowColors(m_panelsBook, [=]
     {
-        if (ColorScheme::GetWindowMode(m_panelsBook) == ColorScheme::Light)
-            m_panelsBook->SetBackgroundColour(*wxWHITE);
-        else
-            m_panelsBook->SetBackgroundColour(wxNullColour);
+        m_panelsBook->SetBackgroundColour(ColorScheme::Get(Color::ListControlBg));
     });
 
     sizer->Add(m_panelsBook, wxSizerFlags(1).Expand());
@@ -267,13 +259,20 @@ void AccountsPanel::OnSelectAccount(wxDataViewEvent& event)
         return;
     }
 
+    const bool listHasFocus = (wxWindow::FindFocus() == m_list);
+
     SelectAccount(index);
+
+    if (listHasFocus && wxWindow::FindFocus() != m_list)
+    {
+        m_list->SetFocus();
+    }
 }
 
 void AccountsPanel::SelectAccount(unsigned index)
 {
 	m_list->SelectRow(index);
-	m_panelsBook->SetSelection(1 + index);
+	m_panelsBook->ChangeSelection(1 + index);
 }
 
 
