@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2015-2023 Vaclav Slavik
+ *  Copyright (C) 2015-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -100,7 +100,7 @@ CrowdinLoginPanel::CrowdinLoginPanel(wxWindow *parent, int flags)
 
     auto buttons = new wxBoxSizer(wxHORIZONTAL);
     sizer->Add(buttons, wxSizerFlags().Expand().Border(wxBOTTOM, 1));
-    buttons->Add(learnMore, wxSizerFlags().Center().Border(wxLEFT, PX(LearnMoreLink::EXTRA_INDENT)));
+    buttons->Add(learnMore, wxSizerFlags().Center());
     buttons->AddSpacer(PX(60));
     buttons->AddStretchSpacer();
     buttons->Add(m_signIn, wxSizerFlags());
