@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2023 Vaclav Slavik
+ *  Copyright (C) 2014-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -55,7 +55,7 @@ public:
 class AutoWrappingText : public wxStaticText
 {
 public:
-    AutoWrappingText(wxWindow *parent, const wxString& label);
+    AutoWrappingText(wxWindow *parent, wxWindowID winid, const wxString& label);
 
     void SetLanguage(Language lang);
     void SetAlignment(TextDirection dir);
@@ -121,7 +121,7 @@ private:
 class SelectableAutoWrappingText : public AutoWrappingText
 {
 public:
-    SelectableAutoWrappingText(wxWindow *parent, const wxString& label);
+    SelectableAutoWrappingText(wxWindow *parent, wxWindowID winid, const wxString& label);
 };
 
 
@@ -162,12 +162,6 @@ class LearnMoreLink : public wxHyperlinkCtrl
 {
 public:
     LearnMoreLink(wxWindow *parent, const wxString& url, wxString label = wxString(), wxWindowID winid = wxID_ANY);
-
-#if defined(__WXOSX__)
-    static const int EXTRA_INDENT = 2;
-#elif defined(__WXMSW__) || defined(__WXGTK__)
-    static const int EXTRA_INDENT = 0;
-#endif
 };
 
 class LearnMoreLinkXmlHandler : public wxXmlResourceHandler
@@ -286,17 +280,4 @@ private:
     class MultilineTextRenderer;
 };
 
-
-/// Fix for a wxStaticLine bug on macOS Ventura
-#if defined(__WXOSX__) && !wxCHECK_VERSION(3,2,3)
-class StaticLine : public wxStaticLine
-{
-public:
-    StaticLine(wxWindow *parent, wxWindowID id);
-};
-#else
-typedef wxStaticLine StaticLine;
-#endif
-
-
 #endif // Poedit_customcontrols_h
