@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2024 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
@@ -161,14 +161,7 @@ class PoeditListCtrl : public wxDataViewCtrl
             EnsureVisible(item);
 
         #ifndef __WXOSX__
-          #if wxCHECK_VERSION(3,1,1)
             wxDataViewEvent event(wxEVT_DATAVIEW_SELECTION_CHANGED, this, item);
-          #else
-            wxDataViewEvent event(wxEVT_DATAVIEW_SELECTION_CHANGED, GetId());
-            event.SetEventObject(this);
-            event.SetModel(GetModel());
-            event.SetItem(item);
-          #endif
             ProcessWindowEvent(event);
         #endif
         }
@@ -319,7 +312,7 @@ class PoeditListCtrl : public wxDataViewCtrl
 
             wxColour m_clrID, m_clrInvalid, m_clrFuzzy;
             wxString m_clrContextFg, m_clrContextBg;
-            wxIcon m_iconComment, m_iconBookmark, m_iconError, m_iconWarning;
+            wxIcon m_iconComment, m_iconError, m_iconWarning;
         };
 
 
