@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2001-2023 Vaclav Slavik
+ *  Copyright (C) 2001-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -49,10 +49,6 @@
 #include <wx/windowptr.h>
 #include <wx/sizer.h>
 
-#if !wxCHECK_VERSION(3,1,1)
-    #define wxGETTEXT_IN_CONTEXT(ctxt, s) wxGetTranslation((s))
-#endif
-
 #include "catalog.h"
 #include "cat_update.h"
 #include "edapp.h"
@@ -241,7 +237,7 @@ ManagerFrame::~ManagerFrame()
     if (sel != -1)
     {
         cfg->Write("manager_last_selected",
-                   (long)m_listPrj->GetClientData(sel));
+                   (long)(wxIntPtr)m_listPrj->GetClientData(sel));
     }
 
     ms_instance = NULL;
