@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2023 Vaclav Slavik
+ *  Copyright (C) 2000-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -36,7 +36,7 @@ public:
     static std::unique_ptr<PoeditPreferencesEditor> Create();
 
 private:
-    PoeditPreferencesEditor() {}
+    PoeditPreferencesEditor();
 };
 
 #endif // Poedit_prefsdlg_h
\ No newline at end of file
