@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2023 Vaclav Slavik
+ *  Copyright (C) 2014-2024 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -29,7 +29,6 @@
 #include "str_helpers.h"
 
 #include <unicode/uchar.h>
-
 #include <regex>
 
 namespace
@@ -205,6 +204,7 @@ std::wregex REOBJ_COMMON_PLACEHOLDERS(
                 //      +--------------------------------------------------- %var% (Twig)
                 //
                 RegexSyntaxHighlighter::flags);
+const wchar_t* COMMON_PLACEHOLDERS_TRIGGER_CHARS = L"{%";
 
 // WebExtension-like $foo$ placeholders
 std::wregex REOBJ_DOLLAR_PLACEHOLDERS(LR"(\$[A-Za-z0-9_]+\$)", RegexSyntaxHighlighter::flags);
@@ -253,8 +253,21 @@ SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kin
     bool needsHTML = (kindsMask & Markup);
     if (needsHTML)
     {
-        needsHTML = std::regex_search(str::to_wstring(item.GetString()), REOBJ_HTML_MARKUP) ||
-                (item.HasPlural() && std::regex_search(str::to_wstring(item.GetPluralString()), REOBJ_HTML_MARKUP));
+        needsHTML = false;
+
+        str::wstring_conv_t str1 = str::to_wstring(item.GetString());
+        if (str1.find(L"<") != std::wstring::npos && std::regex_search(str1, REOBJ_HTML_MARKUP))
+        {
+            needsHTML = true;
+        }
+        else if (item.HasPlural())
+        {
+            str::wstring_conv_t strp = str::to_wstring(item.GetString());
+            if (strp.find(L"<") != std::wstring::npos && std::regex_search(strp, REOBJ_HTML_MARKUP))
+            {
+                needsHTML = true;
+            }
+        }
     }
     bool needsGenericPlaceholders = (kindsMask & Placeholder);
     if (needsGenericPlaceholders)
@@ -266,8 +279,21 @@ SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kin
         }
         else
         {
-            needsGenericPlaceholders = std::regex_search(str::to_wstring(item.GetString()), REOBJ_COMMON_PLACEHOLDERS) ||
-                    (item.HasPlural() && std::regex_search(str::to_wstring(item.GetPluralString()), REOBJ_COMMON_PLACEHOLDERS));
+            needsGenericPlaceholders = false;
+
+            str::wstring_conv_t str1 = str::to_wstring(item.GetString());
+            if (str1.find_first_of(COMMON_PLACEHOLDERS_TRIGGER_CHARS) != std::wstring::npos && std::regex_search(str1, REOBJ_COMMON_PLACEHOLDERS))
+            {
+				needsGenericPlaceholders = true;
+			}
+            else if (item.HasPlural())
+            {
+                str::wstring_conv_t strp = str::to_wstring(item.GetString());
+                if (strp.find_first_of(COMMON_PLACEHOLDERS_TRIGGER_CHARS) != std::wstring::npos && std::regex_search(strp, REOBJ_COMMON_PLACEHOLDERS))
+                {
+                    needsGenericPlaceholders = true;
+                }
+            }
         }
     }
 
